<!DOCTYPE html>
<html>
<head>
<style>
.datagrid table {border-collapse: collapse; text-align: left; width: 100%; } .datagrid {overflow: auto; font: normal 12px/150% Arial, Helvetica, sans-serif; background: #fff; border: 1px solid #2955D9;
 -webkit-border-radius: 3px; -moz-border-radius: 3px; border-radius: 3px; }
.datagrid table td, .datagrid table th { padding: 3px 10px; }.datagrid table thead th {background:-webkit-gradient( linear, left top, left bottom, color-stop(0.05, #2955D9), color-stop(1, #2955D9) );background:-moz-linear-gradient( center top, #2955D9 5%, #2955D9 100% );filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#2955D9', endColorstr='#2955D9');background-color:#2955D9; color:#FFFFFF; font-size: 12px; font-weight: bold; border-left: 1px solid #0070A8; } .datagrid table thead th:first-child { border: none; }.datagrid table tbody td { color: #00496B; border-left: 0px solid #E1EEF4;font-size: 12px;font-weight: normal; }.datagrid table tbody td:first-child { border-left: none; }.datagrid table tbody tr:last-child td { border-bottom: none; }.datagrid table tfoot td div { border-top: 1px solid #2955D9;background: #E1EEF4;} .datagrid table tfoot td { padding: 0; font-size: 12px } .datagrid table tfoot td div{ padding: 2px; }.datagrid table tfoot td ul { margin: 0; padding:0; list-style: none; text-align: right; }.datagrid table tfoot li { display: inline; }.datagrid table tfoot li a { text-decoration: none; display: inline-block;  padding: 2px 8px; margin: 1px;color: #FFFFFF;border: 1px solid #2955D9;-webkit-border-radius: 3px; -moz-border-radius: 3px; border-radius: 3px; background:-webkit-gradient( linear, left top, left bottom, color-stop(0.05, #2955D9), color-stop(1, #2955D9) );background:-moz-linear-gradient( center top, #2955D9 5%, #2955D9 100% );filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#2955D9', endColorstr='#2955D9');background-color:#2955D9; }.datagrid table tfoot ul.active, .datagrid table tfoot ul a:hover { text-decoration: none;border-color: #2955D9; color: #FFFFFF; background: none; background-color:#2955D9;}div.dhtmlx_window_active, div.dhx_modal_cover_dv { position: fixed !important; }#row tr.one:hover {background-color: #ff8000; color: white;}#row tr.two:hover {background-color: #ff8000; color: white;}#row tr.one {background-color: #dcdcdc;}#row tr.two {background-color: #fcfcfc;}
ul{ margin-left: 0px;margin-top: 0px; list-style-type: none; margin:0; padding: 0;}

h2 {
font-weight:bold;
font-style:italic;
color:#FF8033;
letter-spacing:2pt;
font-size:28px;
text-align:center;
font-family:helvetica, sans-serif;
line-height:1;
}
h3 {
font-weight:bold;
font-style:italic;
color:#5566F7;
word-spacing:0pt;
font-size:17px;
text-align:left;
font-family:helvetica, sans-serif;
line-height:1;
}
body {
font-weight:normal;
color:#000000;
word-spacing:0pt;
font-size:12px;
text-align:left;
font-family:helvetica, sans-serif;
line-height:1;
}

</style>
<script src="http://ajax.aspnetcdn.com/ajax/jQuery/jquery-1.12.0.min.js"></script>
<script src="{{ url_for('static', filename='script.js') }}"></script>
<script type="text/javascript">
function updateClock (){
  var currentTime = new Date ( );
  var utcts = new Date;
  var n = utcts.getTimezoneOffset();


  utcts.setMinutes ( currentTime.getMinutes() + n );

  //var utcts = Date.UTC(now.getUTCFullYear(),now.getUTCMonth(), now.getUTCDate() , now.getUTCHours(), now.getUTCMinutes(), now.getUTCSeconds(), now.getUTCMilliseconds());

  //Get the hours for updating clock
  var currentHours = currentTime.getHours ();
  var utcHours = utcts.getHours ();

  //Get the minuts for updating clock
  var currentMinutes = currentTime.getMinutes ();
  var utcMinutes = utcts.getMinutes ();

  //Get the secconds for updating clock
  var currentSeconds = currentTime.getSeconds ();
  var utcSeconds = utcts.getSeconds ();

  // Pad the minutes and seconds with leading zeros, if required
  currentMinutes = ( currentMinutes < 10 ? "0" : "" ) + currentMinutes;
  currentSeconds = ( currentSeconds < 10 ? "0" : "" ) + currentSeconds;
  utcMinutes = ( utcMinutes < 10 ? "0" : "" ) + utcMinutes;
  utcSeconds = ( utcSeconds < 10 ? "0" : "" ) + utcSeconds;

  // Choose either "AM" or "PM" as appropriate
  // var timeOfDay = ( currentHours < 12 ) ? "AM" : "PM";

  // Convert the hours component to 12-hour format if needed
  //currentHours = ( currentHours > 12 ) ? currentHours - 12 : currentHours;

  // Convert an hours component of "0" to "12"
  //currentHours = ( currentHours == 0 ) ? 12 : currentHours;

  // Compose the string for display
  var currentTimeString = currentHours + ":" + currentMinutes + ":" + currentSeconds;
  var utcTimeString = utcHours + ":" + utcMinutes + ":" + utcSeconds;

  // Update the time display
  document.getElementById("localtime").firstChild.nodeValue = currentTimeString;
  document.getElementById("utctime").firstChild.nodeValue = utcTimeString;
}
</script>
<link rel="shortcut icon" href="{{ url_for('static', filename='favicon.ico') }}">

<meta charset='utf-8'>
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="stylesheet" href="{{ url_for('static', filename='menustyles.css') }}">
<title>RXwave.com - Online Scanning Website</title>

</head>
<body onload="updateClock(); setInterval('updateClock()', 1000 )">
<div class='traditional'>
<table class='traditional' width=100% border=0>
  <tr>
    <td colspan=2>
      <table width=100%>
        <tr>
          <td width=15%>
            <a href="/"><img src='{{ url_for('static', filename='RXWave.gif') }}' height=80></a>
          </td>
          <td width=70% align=center>
          </td>
          <td width=10% align=right valign=bottom>
            <a href="/login" target="main">Login</a>
          </td>
        </tr>
      </table>
    </td>
  </tr>
  <tr>
    <td width='10%' align='left' valign='top'>
<div id='cssmenu' align='left' style=" margin-left: 0px;margin-top: 0px;">
 <ul style="-webkit-border-radius: 3px; -moz-border-radius: 3px; border-radius: 3px; ">
   <li class='active'><a href='/home'><span>Home</span></a></li>

   <li class='open'><a href='http://www.rxwave.com/'><span>RXWave.com</span></a>
   </li>

 
   <li class='has-sub'><a href='/logs'><span>Logs</span></a>
      <ul>
         <li><a href='/logs/pirec'><span>PiRec</span></a></li>
         <li><a href='/logs/piqueue' class='last'><span>PiQueue</span></a></li>
      </ul>
   </li>

   <li class='open'><a href='/stats'><span>Stats</span></a>
   </li>


</ul>
</div>

<table width=100%>
  <tr><td align='center'>Local: <span id=localtime> </span></td></tr>
  <tr><td align='center'>UTC: <span id=utctime> </span></td></tr>
</table>

    </td>
    <td align='left' valign='top'>
      {{ item }}
    </td>
  </tr>
</table>
</div>
<script type="text/javascript">

jQuery(document).ready(function($) {
  $(".clickable").click(function() {window.document.location = $(this).data("href");});
  $("#row tr:nth-child(odd)").addClass("two");
  $("#row tr:nth-child(even)").addClass("one");
});







</script>
</body>
</html>

