@import url(http://fonts.googleapis.com/css?family=Lato); @charset 
"UTF-8"; /* Base Styles */
#cssmenu, cssmenu ul, cssmenu li, cssmenu a {
  margin: 0;
  padding: 0;
  border: 0;
  list-style: none;
  font-weight: normal;
  text-decoration: none;
  line-height: 1;
  #font-family: 'Lato', sans-serif;
  font-family: Arial, Helvetica, sans-serif;
  #font: normal 12px/150%
  font-size: 14px;
  position: relative;
}
#cssmenu a {
  line-height: 1.3;
  padding: 6px 15px;
}
#cssmenu {
  width: 200px;
  margin-left: 0px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px; 
  border-radius: 3px; 

}
#cssmenu > ul > li {
  cursor: pointer;
  background: #000;
  border-bottom: 1px solid #4c4e53;
}
#cssmenu > ul > li:last-child {
  border-bottom: 1px solid #3e3d3c;
}
#cssmenu > ul > li > a {
  font-size: 13px;
  display: block;
  color: #ffffff;
  text-shadow: 0 1px 1px #000;
  background: #64676e;
  background: -moz-linear-gradient(#64676e 0%, #4c4e53 100%);
  background: -webkit-gradient(linear, left top, left bottom, 
color-stop(0%, #64676e), color-stop(100%, #4c4e53));
  background: -webkit-linear-gradient(#64676e 0%, #4c4e53 100%);
  background: linear-gradient(#64676e 0%, #4c4e53 100%);
}
#cssmenu > ul > li > a:hover {
  text-decoration: none;
}
#cssmenu > ul > li.active {
-webkit-border-radius: 3px; -moz-border-radius: 3px; border-radius: 3px; 
  border-bottom: none;
}
#cssmenu > ul > li.active > a {
  background: #2955D9;
  background: -moz-linear-gradient(#2955D9 0%, #4D71DF 100%);
  background: -webkit-gradient(linear, left top, left bottom, 
color-stop(0%, #2955D9), color-stop(100%, #4D71DF));
  background: -webkit-linear-gradient(#2955D9 0%, #4D71DF 100%);
  background: linear-gradient(#2955D9 0%, #4D71DF 100%);
  color: #FFFFFF;
  text-shadow: 0 1px 1px #111111;
}
#cssmenu > ul > li.has-sub > a:after {
  content: "";
  position: absolute;
  top: 10px;
  right: 10px;
  border: 5px solid transparent;
  border-left: 5px solid #ffffff;
}
#cssmenu > ul > li.has-sub.active > a:after {
  right: 14px;
  top: 12px;
  border: 5px solid transparent;
  border-top: 5px solid #4e5800;
}
/* Sub menu */
#cssmenu ul ul {
  padding: 0;
  display: none;
}
#cssmenu ul ul a {
  background: #efefef;
  display: block;
  color: #797979;
  font-size: 13px;
}
#cssmenu ul ul li {
  border-bottom: 1px solid #c9c9c9;
}
#cssmenu ul ul li.odd a {
  background: #e5e5e5;
}
#cssmenu ul ul li:last-child {
  border: none;
}
